"{ Package: 'jv:tea/compiler' }"

"{ NameSpace: Smalltalk }"

LibraryDefinition subclass:#jv_tea_compiler
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'* Projects & Packages *'
!


!jv_tea_compiler class methodsFor:'description'!

excludedFromPreRequisites
    "list packages which are to be explicitely excluded from the automatic constructed
     prerequisites list. If empty, everything that is found along the inheritance of any of
     my classes is considered to be a prerequisite package."

    ^ #(
    )
!

mandatoryPreRequisites
    "list packages which are mandatory as a prerequisite.
     This are packages containing superclasses of my classes and classes which
     are extended by myself.
     They are mandatory, because we need these packages as a prerequisite for loading and compiling.
     This method is generated automatically,
     by searching along the inheritance chain of all of my classes."

    ^ #(
        #'stx:goodies/refactoryBrowser/helpers'    "RBAbstractClass - superclass of TClass"
        #'stx:goodies/refactoryBrowser/parser'    "RBBlockNode - extended"
        #'stx:goodies/sunit'    "TestAsserter - superclass of TParserTests"
        #'stx:libbasic'    "LibraryDefinition - superclass of jv_tea_compiler"
    )
!

referencedPreRequisites
    "list packages which are a prerequisite, because they contain
     classes which are referenced by my classes.
     We do not need these packages as a prerequisite for compiling or loading,
     however, a class from it may be referenced during execution and having it
     unloaded then may lead to a runtime doesNotUnderstand error, unless the caller
     includes explicit checks for the package being present.
     This method is generated automatically,
     by searching all classes (and their packages) which are referenced by my classes."

    ^ #(
    )
!

subProjects
    "list packages which are known as subprojects.
     The generated makefile will enter those and make there as well.
     However: they are not forced to be loaded when a package is loaded;
     for those, redefine requiredPrerequisites."

    ^ #(
    )
! !

!jv_tea_compiler class methodsFor:'description - contents'!

classNamesAndAttributes
    "lists the classes which are to be included in the project.
     Each entry in the list may be: a single class-name (symbol),
     or an array-literal consisting of class name and attributes.
     Attributes are: #autoload or #<os> where os is one of win32, unix,..."

    ^ #(
        "<className> or (<className> attributes...) in load order"
        TBinding
        TClass
        TCompiler
        TFormatter
        TMetaclass
        TMethod
        TParser
        (TParserTests autoload)
        TProgramNodeVisitor
        TScope
        TType
        TTypeNode
        TTypeSpecNode
        #'jv_tea_compiler'
        TFunctionBinding
        TSemanticAnalyzer
        TSimpleType
        TSimpleTypeNode
        TTypeChecker
        TUnionType
        TUnionTypeNode
        TValueBinding
        TConstantBinding
        TVariableBinding
        TArgumentBinding
        TLocalBinding
    )
!

extensionMethodNames
    "list class/selector pairs of extensions.
     A correponding method with real names must be present in my concrete subclasses"

    ^ #(
        RBBlockNode returnTypeSpec
        RBBlockNode returnTypeSpec:
        RBMethodNode returnTypeSpec
        RBMethodNode returnTypeSpec:
        RBVariableNode typeSpec
        RBVariableNode typeSpec:
        RBBlockNode scope
        RBBlockNode scope:
        RBMethodNode scope
        RBMethodNode scope:
        RBProgramNode binding
        RBProgramNode binding:
        RBProgramNode scope
        RBReturnNode binding
        RBReturnNode binding:
    )
! !

!jv_tea_compiler class methodsFor:'description - project information'!

companyName
    "Returns a company string which will appear in <lib>.rc.
     Under win32, this is placed into the dlls file-info"

    ^ 'My Company'
!

description
    "Returns a description string which will appear in nt.def / bc.def"

    ^ 'Class Library'
!

legalCopyright
    "Returns a copyright string which will appear in <lib>.rc.
     Under win32, this is placed into the dlls file-info"

    ^ 'My CopyRight or CopyLeft'
!

productName
    "Returns a product name which will appear in <lib>.rc.
     Under win32, this is placed into the dlls file-info.
     This method is usually redefined in a concrete application definition"

    ^ 'LibraryName'
! !

!jv_tea_compiler class methodsFor:'documentation'!

version_HG
    ^ '$Changeset: <not expanded> $'
! !

